diff --git a/common/source/java/ch/systemsx/cisd/common/highwatermark/HighwaterMarkWatcher.java b/common/source/java/ch/systemsx/cisd/common/highwatermark/HighwaterMarkWatcher.java
index 3dc7b938a67d9a682efbc9ac91593cd976b1a22b..9cadcc4664e64257e2bd6218d4c34f3aff91b452 100644
--- a/common/source/java/ch/systemsx/cisd/common/highwatermark/HighwaterMarkWatcher.java
+++ b/common/source/java/ch/systemsx/cisd/common/highwatermark/HighwaterMarkWatcher.java
@@ -45,6 +45,8 @@ import ch.systemsx.cisd.common.utilities.FileUtilities;
 public final class HighwaterMarkWatcher implements Runnable
 {
 
+    private static final String UNSPECIFIED = "unspecified";
+
     private final static IFreeSpaceProvider DEFAULT_FREE_SPACE_PROVIDER =
             new DefaultFreeSpaceProvider();
 
@@ -95,6 +97,10 @@ public final class HighwaterMarkWatcher implements Runnable
 
     public final static String displayKilobyteValue(final long value)
     {
+        if (value < 0)
+        {
+            return UNSPECIFIED;
+        }
         return FileUtilities.byteCountToDisplaySize(value * FileUtils.ONE_KB);
     }
diff --git a/common/source/java/ch/systemsx/cisd/common/highwatermark/FileWithHighwaterMark.java b/common/source/java/ch/systemsx/cisd/common/highwatermark/FileWithHighwaterMark.java
index 408635aacbf07dc6ed25b7d415fe11f887a2efda..92fe45ab73e62717566db15d8fe5fa17a95916b3 100644
--- a/common/source/java/ch/systemsx/cisd/common/highwatermark/FileWithHighwaterMark.java
+++ b/common/source/java/ch/systemsx/cisd/common/highwatermark/FileWithHighwaterMark.java
@@ -35,6 +35,8 @@ import ch.systemsx.cisd.common.utilities.PropertyUtils;
 public final class FileWithHighwaterMark extends AbstractHashable implements Serializable
 {
 
+    public static final int DEFAULT_HIGHWATER_MARK = -1;
+
     private static final long serialVersionUID = 1L;
 
     /**
@@ -45,17 +47,17 @@ public final class FileWithHighwaterMark extends AbstractHashable implements Ser
 
     private final File path;
 
-    private final long highwaterMark;
+    private final long highwaterMarkInKb;
 
     /**
      * @param file the file path.
      * @param highwaterMark the high water mark. <code>-1</code> means that the system will not be
      *            watching.
      */
-    public FileWithHighwaterMark(final File file, final long highwaterMark)
+    public FileWithHighwaterMark(final File file, final long highwaterMarkInKb)
     {
         this.path = file;
-        this.highwaterMark = highwaterMark;
+        this.highwaterMarkInKb = highwaterMarkInKb;
     }
 
     /**
@@ -63,7 +65,7 @@ public final class FileWithHighwaterMark extends AbstractHashable implements Ser
      */
     public FileWithHighwaterMark(final File path)
     {
-        this(path, -1);
+        this(path, DEFAULT_HIGHWATER_MARK);
     }
 
     /**
@@ -79,10 +81,10 @@ public final class FileWithHighwaterMark extends AbstractHashable implements Ser
         assert properties != null : "Unspecified properties";
         assert StringUtils.isNotBlank(filePropertyKey) : "File property key is blank";
         final String filePath = PropertyUtils.getMandatoryProperty(properties, filePropertyKey);
-        final long highwaterMark =
+        final long highwaterMarkInKb =
                 PropertyUtils.getLong(properties, filePropertyKey.concat(".").concat(
                         HIGHWATER_MARK_PROPERTY_KEY), -1L);
-        return new FileWithHighwaterMark(new File(filePath), highwaterMark);
+        return new FileWithHighwaterMark(new File(filePath), highwaterMarkInKb);
     }
 
     /**
@@ -104,6 +106,6 @@ public final class FileWithHighwaterMark extends AbstractHashable implements Ser
      */
     public final long getHighwaterMark()
     {
-        return highwaterMark;
+        return highwaterMarkInKb;
     }
 }
@@ -45,17 +47,17 @@ public final class FileWithHighwaterMark extends AbstractHashable implements Ser
     /**
      * @param file the file path.
-     * @param highwaterMark the high water mark. <code>-1</code> means that the system will not be
-     *            watching.
+     * @param highwaterMarkInKb the high water mark in <i>kilobytes</i>. <code>-1</code> means
+     *            that the system will not be watching.
      */